@@ -1,3 +1,12 @@
+/*
+ * The Sleuth Kit
+ *
+ * Brian Carrier [carrier <at> sleuthkit [dot] org]
+ * Copyright (c) 2019-2020 Brian Carrier.  All Rights reserved
+ * Copyright (c) 2018-2019 BlackBag Technologies.  All Rights reserved
+ *
+ * This software is distributed under the Common Public License 1.0
+ */
 #include "../util/crypto.hpp"
 #include "apfs_fs.hpp"
 #include "tsk_apfs.hpp"
@@ -590,7 +599,7 @@ const std::vector<APFSFileSystem::snapshot_t> APFSFileSystem::snapshots()
 
   const APFSSnapshotMetaBtreeNode snap_tree{_pool, fs()->snap_meta_tree_oid};
 
-  using key_type = struct {
+  struct key_type {
     uint64_t xid_and_type;
 
     inline uint64_t snap_xid() const noexcept {
